@@ -29,36 +29,57 @@
 #'      target ratio \eqn{q = \beta/\alpha} (argument \code{beta_alpha})}
 #' }
 #'
-#' Prospective and compromise analyses utilize the
-#' \code{\link[SimDesign]{runSimulation}} function, while the remaining three
-#' approaches utilize the stochastic root solving methods in the function
-#' \code{\link[SimDesign]{SimSolve}}.
-#' See the example below for a demonstration with an independent samples t-test
-#' analysis.
-#'
-#' @param ... expression to use in the simulation that returns a \code{numeric}
-#'   vector containing only p-value information, where the first p-value
-#'   in this vector is treated as the focus for all analyses other than prospective/post-hoc power,
-#'   or a similarly structure \code{logical} vector when utilizing confidence intervals (CIs).
-#'
-#'   Internally the first expression is passed to either \code{\link[SimDesign]{SimSolve}} or
+#'  To understand how the package is structured, the first expression in the \code{...} argument,
+#'  which contains the simulation experiment definition for a single sample,
+#'  is passed to either \code{\link[SimDesign]{SimSolve}} or
 #'  \code{\link[SimDesign]{runSimulation}} depending on which element (including
 #'  the \code{power} and \code{sig.level} arguments) is set to \code{NA}. For instance,
 #'  \code{Spower(p_t.test(n=50, d=.5))} will perform a prospective/post-hoc power evaluation since
 #'  \code{power = NA} by default, while \code{Spower(p_t.test(n=NA, d=.5), power = .80)}
 #'  will perform an a priori power analysis to solve the missing \code{n} argument.
 #'
-#'  For expected power computations the arguments to this expression can themselves
+#'  For expected power computations, the arguments to the simulation experiment arguments can
 #'  be specified as a function to reflect the prior uncertainty. For instance, if
 #'  \code{d_prior <- function() rnorm(1, mean=.5, sd=1/8)} then
 #'  \code{Spower(p_t.test(n=50, d=d_prior())} will compute the expected power
 #'  over the prior sampling distribution for \code{d}
 #'
-#' @param power power level to use. If set to \code{NA} then the empirical power
-#'   will be estimated given the fixed \code{...} inputs
-#'   (e.g., for prospective/post-hoc power analysis)
+#' @param ... expression to use in the simulation that returns a \code{numeric}
+#'   vector containing either the p-value (under the null hypothesis), the
+#'   probability of the alternative hypothesis in the Bayesian setting,
+#'   where the first numeric value
+#'   in this vector is treated as the focus for all analyses other than prospective/post-hoc power.
+#'   This corresponds to the \code{alpha} value used to flag samples
+#'   as 'significant' when evaluating the null hypothesis
+#'   (via p-values; \eqn{P(D|H_0)}),
+#'   where any returned p-value less that \code{sig.level} indicates significance.
+#'   However, if \code{sig.direction = 'above'} then only values
+#'   above \code{sig.level} are flagged as significant, which is useful
+#'   in Bayesian posterior probability contexts that focus on the alternative
+#'   hypothesis, \eqn{P(H_1|D)}.
 #'
-#' @param maxiter maximum number of stochastic root-solving iterations
+#'   Alternatively, a \code{logical} vector can be returned (e.g., when using confidence intervals (CIs) or
+#'   evaluating regions of practical equivalence (ROPEs)), where the average of these
+#'   TRUE/FALSE vector corresponds to the empirical power.
+#'
+#' For \code{\link{SpowerCurve}} and \code{\link{SpowerBatch}},
+#' first expression input must be identical to \code{...} in
+#' \code{\link{Spower}}, while the remaining named inputs must match the arguments
+#' to this expression to indicate which variables should be modified in the
+#' resulting power curves. Providing \code{NA} values is also supported to
+#' solve the missing component.  Note that only the first three named
+#' arguments in \code{\link{SpowerCurve}} will be plotted using
+#' the x-y, colour, and facet wrap aesthetics, respectively. However,
+#' if necessary the data can be extracted for further visualizations via
+#' \code{\link[ggplot2]{ggplot_build}} to provide more customized control
+#'
+#' @param power power level to use. If set to \code{NA} (default)
+#'   then the empirical power  will be estimated given the fixed \code{...} inputs
+#'   (e.g., for prospective/post-hoc power analysis). For
+#'   \code{\link{SpowerCurve}} and \code{\link{SpowerBatch}} this can be a vector
+#'
+#' @param maxiter maximum number of stochastic root-solving iterations.
+#'   Default is 150, though set to 50 for \code{\link{SpowerCurve}}
 #'
 #' @param select a character vector indicating which elements to
 #'   extract from the provided stimulation experiment function. By default, all elements
@@ -68,19 +89,31 @@
 #'   results post-analysis use \code{\link[SimDesign]{SimResults}} to allow manual
 #'   summarizing of the stored results (applicable only with prospective/post-hoc power)
 #'
-#' @param sig.level alpha level to use. If set to \code{NA} then the empirical
-#'   alpha will be estimated given the fixed \code{conditions} input
+#' @param sig.level alpha level to use (default is \code{.05}). If set to \code{NA} then the value will
+#'   be estimated given the fixed \code{conditions} input
 #'   (e.g., for criterion power analysis). Only used when the value returned
-#'   from the experiment is a \code{numeric} (p-value).
+#'   from the experiment is a \code{numeric} (e.g., a p-value, or a
+#'   posterior probability; see \code{sig.direction}).
 #'
 #'   If the return of the supplied experiment is a
-#'   \code{logical}, which generally indicates that a confidence interval (CI)
-#'   approach were used,
-#'   then an argument such as \code{conf.level} should be included
-#'   in the simulation experiment to indicate the explicit CI
-#'   criteria, and so that this can be modified directly as well
+#'   \code{logical} then this argument will be entirely ignored. As such,
+#'   arguments such as \code{conf.level} should be included
+#'   in the simulation experiment definition itself
+#'   to indicate the explicit inferential
+#'   criteria, and so that this argument can be manipulated should the need arise.
 #'
-#' @param interval search interval to use when \code{\link[SimDesign]{SimSolve}} is required.
+#' @param sig.direction a character vector that is either \code{'below'}
+#'   (default) or \code{'above'} to indicate which direction relative to
+#'   \code{sig.level} is considered significant. This is useful, for instance,
+#'    when forming cutoffs for Bayesian
+#'   posterior probabilities organized to show support
+#'   for the hypothesis of interest (\eqn{P(H_1|D)}). As an example,
+#'   setting \code{sig.level = .95} with \code{sig.direction = 'above'}
+#'   flags a sample as 'significant' whenever the
+#'   posterior probability is greater than .95.
+#'
+#' @param interval required search interval to use when \code{\link[SimDesign]{SimSolve}} is called
+#'   to perform stochastic root solving.
 #'   Note that for compromise analyses, where the \code{sig.level} is set to
 #'   \code{NA}, if not set explicitly then the interval will default to \code{c(0,1)}
 #'
@@ -90,7 +123,8 @@
 #'  See \code{\link[SimDesign]{timeFormater}} for further specifications
 #'
 #' @param replications number of replications to use when
-#'   \code{\link[SimDesign]{runSimulation}} is required
+#'   \code{\link[SimDesign]{runSimulation}} is required. Default is 10000,
+#'   though set to 2500 for \code{\link{SpowerCurve}}
 #'
 #' @param lastSpower a previously returned \code{Spower} object to be updated.
 #'   Use this if you want to continue where an estimate left off but wish to increase the
@@ -105,11 +139,11 @@
 #'
 #'   If missing, automatically set to \code{FALSE} if \code{interval} contains
 #'   non-integer numbers or the range is less than 5, as well as
-#'   when \code{sig.level = NA}, though in general this should be set explicitly
+#'   when \code{sig.level = NA}
 #'
 #' @param beta_alpha (optional) ratio to use in compromise analyses corresponding to
 #'   the Type II errors (beta) over the Type I error (alpha). Ratios greater
-#'   than 1 indicate that Type I errors are worse than Type II, while ratios
+#'   than \eqn{q = \beta/\alpha = 1} indicate that Type I errors are worse than Type II, while ratios
 #'   less than one the opposite. A ratio equal to 1 gives an equal trade-off
 #'   between Type I and Type II errors
 #'
@@ -163,7 +197,7 @@
 #' ############################
 #'
 #' # Internally defined p_t.test function
-#' args(p_t.test)    # missing arguments required for Spower()
+#' args(p_t.test)    # missing arguments required
 #' # help(p_t.test)  # additional information
 #'
 #' # p_* functions generate data and return single p-value
@@ -395,12 +429,14 @@
 #'
 #' }
 Spower <- function(..., power = NA, sig.level=.05, interval,
-				   beta_alpha, replications=10000, integer,
+				   beta_alpha, sig.direction = 'below',
+				   replications=10000, integer,
 				   parallel = FALSE, cl = NULL, packages = NULL,
 				   ncores = parallelly::availableCores(omit = 1L),
 				   predCI = 0.95, predCI.tol = .01, verbose = TRUE,
 				   check.interval = FALSE, maxiter=150, wait.time = NULL,
 				   lastSpower = NULL, select = NULL, control = list()){
+	stopifnot(sig.direction %in% c('below', 'above'))
 	if(missing(beta_alpha)) beta_alpha <- NULL
 	if(!is.null(cl)) parallel <- TRUE
 	control$useAnalyseHandler <- FALSE
@@ -432,7 +468,7 @@ Spower <- function(..., power = NA, sig.level=.05, interval,
 		predCI.tol <- NULL
 	}
 	summarise <- Internal_Summarise
-	fixed_objects <- list(sig.level=sig.level)
+	fixed_objects <- list(sig.level=sig.level, sig.direction=sig.direction)
 	expr <- match.call(expand.dots = FALSE)$...[[1]]
 	expr <- match.call(eval(expr[[1]], envir = pf), expr)
 	if(!is.null(expr[-1])){
@@ -553,7 +589,8 @@ sim_function_aug <- function(condition, dat, fixed_objects){
 }
 
 #' @rdname Spower
-#' @param x object of class \code{'Spower'}
+#' @param x object of class \code{'Spower'}. If \code{\link{SpowerBatch}} were used
+#'   the this will be a \code{list}
 #' @export
 print.Spower <- function(x, ...){
 	lste <- attr(x, 'Spower_extra')
@@ -600,3 +637,12 @@ print.Spower <- function(x, ...){
 	invisible(NULL)
 }
 
+#' @rdname Spower
+#' @export
+as.data.frame.Spower <- function(x, ...){
+	class(x) <- 'data.frame'
+	pick <- which(colnames(x) == 'REPLICATIONS')
+	if(length(pick))
+		x <- x[, 2:pick-1, drop=FALSE]
+	x
+}
