@@ -1,6 +1,6 @@
 #' Draw power curve from simulation functions
 #'
-#' Draws power curves that either a) estimate the power given a
+#' \code{\link{SpowerCurve}} draws power curves that either a) estimate the power given a
 #' set of varying conditions or b) solves a set of root conditions
 #' given fixed values of power. Confidence/prediction intervals are
 #' included in the output to reflect the estimate uncertainties, though note
@@ -8,65 +8,30 @@
 #' \code{\link{Spower}} as the goal is visualization of competing
 #' variable inputs rather than precision of a given input.
 #'
-#'
-#' @param ... first expression input must be identical to \code{...} in
-#' \code{\link{Spower}}, while the remaining named inputs must match the arguments
-#' to this expression to indicate which variables should be modified in the
-#' resulting power curves. Providing \code{NA} values is also supported to
-#' solve the missing component
-#'
-#' Note that only the first three named arguments will be plotted using
-#' the x-y, colour, and facet wrap aesthetics, respectively. However,
-#' if necessary the data can be extracted for further visualizations via
-#' \code{\link[ggplot2]{ggplot_build}} to provide more customized control
-#'
-#' @param power power level to use. If set to \code{NA} then the empirical power
-#'   will be estimated given the fixed \code{...} input; otherwise,
-#'   can be specified as a vector to solve the missing elements in
-#'   \code{...}
-#'
-#' @param select which arguments to select from simulation experiment.
-#'   See \code{\link{Spower}} for details
-#'
-#' @param maxiter see \code{\link{Spower}}, though set to 50 instead of 150
-#'
-#' @param sig.level see \code{\link{Spower}}
-#'
-#' @param interval search interval to use when \code{\link[SimDesign]{SimSolve}} is required.
-#'   Can be a vector of length two to apply the same interval across
-#'   the \code{varying} information or a \code{matrix} with two columns
-#'   to apply intervals on a per-row basis
-#'
+#' @param batch if \code{\link{SpowerBatch}} were previously used to perform the computations
+#'   then this information can be provided to this \code{batch} argument to avoid
+#'   recomputing
 #' @param plotCI logical; include confidence/prediction intervals in plots?
-#'
-#' @param wait.time see \code{\link{Spower}}
-#' @param replications see \code{\link{Spower}}, though set to 2500 instead of
-#'   10000
-#' @param integer see \code{\link{Spower}}
-#' @param parallel see \code{\link{Spower}}
-#' @param cl see \code{\link{Spower}}
-#' @param ncores see \code{\link{Spower}}
-#' @param control see \code{\link{Spower}}
-#' @param predCI see \code{\link{Spower}}
-#' @param predCI.tol see \code{\link{Spower}}
-#' @param check.interval see \code{\link{Spower}}, though is set to \code{FALSE}
-#'   by default instead
 #' @param plotly logical; draw the graphic into the interactive \code{plotly}
 #'   interface? If \code{FALSE} the ggplot2 object will be returned instead
-#' @param verbose see \code{\link{Spower}}
 #' @return a ggplot2 object automatically rendered with
 #'   \code{plotly} for interactivity
 #' @import ggplot2
 #' @importFrom plotly ggplotly
+#' @rdname Spower
 #' @export
 #'
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
 #'
-#' @seealso \code{\link{Spower}}
+#' @seealso \code{\link{Spower}}, \code{\link{SpowerBatch}}
 #'
 #' @examples
 #' \donttest{
 #'
+#' ##############################################
+#' # SpowerCurve() examples
+#' ##############################################
+#'
 #' # estimate power given varying sample sizes
 #' gg <- p_t.test(d=0.2) |> SpowerCurve(n=c(30, 90, 270, 550))
 #'
@@ -115,63 +80,80 @@
 #'                          d=c(.2, .5, .8),
 #'                          var.equal=c(FALSE, TRUE))
 #'
+#' ########################################
+#'
+#' # If objects were precomputed using SpowerBatch() then
+#' #  these can be plotted instead
+#' p_t.test(d=0.2) |>
+#'   SpowerBatch(n=c(30, 90, 270, 550), replications=1000) -> nbatch
+#' nbatch
+#' as.data.frame(nbatch)
+#'
+#' # plot the results, but avoid further computations
+#' SpowerCurve(batch=nbatch)
+#'
 #' }
 #'
 SpowerCurve <- function(..., interval = NULL, power = NA,
-					   sig.level=.05, replications=2500, integer,
+					   sig.level=.05, sig.direction = 'below', replications=2500, integer,
 					   plotCI=TRUE, plotly=TRUE, parallel = FALSE, cl = NULL,
 					   ncores = parallelly::availableCores(omit = 1L),
 					   predCI = 0.95, predCI.tol = .01, verbose = TRUE,
 					   check.interval=FALSE, maxiter=50, wait.time = NULL,
-					   select = NULL, control = list()){
-	dots <- match.call(expand.dots = FALSE)$...
-	if(is.na(sig.level))
-		stop('solving for sig.level not yet supported', call.=FALSE)
-	if(all(is.na(sig.level))){
-		interval <- c(0,1)
-		integer <- FALSE
-	}
-	expr <- dots[[1]]
-	expr <- match.call(eval(expr[[1]], envir = parent.frame(1)), expr)
-	pick <- if(length(dots) > 1) names(dots[-1]) else NULL
-	if(all(is.na(power))){
-		conditions <- do.call(SimDesign::createDesign, c(dots[-1], sig.level=sig.level, power=power))
-	} else {
-		if(is.null(interval))
-			stop('search interval must be included', call.=FALSE)
-		lst_expr <- as.list(expr)[-1]
-		if(length(lst_expr))
-			lst_expr <- lst_expr[sapply(lst_expr, \(x) is.atomic(x) || is.list(x))]
-		conditions <- do.call(SimDesign::createDesign, c(lst_expr,
-														 dots[-1],
-														 sig.level=list(sig.level),
-														 power=list(power)))
-	}
-	if(!all(rowSums(is.na(conditions)) == 1))
-		stop('Exactly *one* argument must be set to \'NA\' in SpowerCurve(..., power, sig.level)',
-			 call.=FALSE)
-	power <- conditions$power
-	sig.level <- conditions$sig.level
-	if(!is.na(power[1])){
-		if(missing(integer)){
-			integer <- !(has.decimals(interval) || diff(interval) < 5)
-			if(!integer && verbose)
-				message('\nUsing continuous search interval (integer = FALSE).')
+					   select = NULL, batch = NULL, control = list()){
+	if(is.null(batch)){
+		dots <- match.call(expand.dots = FALSE)$...
+		if(is.na(sig.level))
+			stop('solving for sig.level not yet supported', call.=FALSE)
+		if(all(is.na(sig.level))){
+			interval <- c(0,1)
+			integer <- FALSE
 		}
-	} else integer <- FALSE
-	control$nparent <- 2
-	out <- vector('list', nrow(conditions))
-	for(i in 1:length(out)){
-		row <- conditions[i, ]
-		tmpexpr <- expr
-		if(length(pick))
-			tmpexpr[pick] <- row[,pick]
-		out[[i]] <- do.call(Spower, c(tmpexpr,
-									  list(power=power[i], sig.level=sig.level[i], beta_alpha=NULL,
-									  interval=interval, integer=integer, replications=replications,
-									  parallel=parallel, cl=cl, predCI=predCI, predCI.tol=predCI.tol,
-									  verbose=verbose, check.interval=check.interval,
-									  maxiter=maxiter, wait.time=wait.time, select=select, control=control)))
+		expr <- dots[[1]]
+		expr <- match.call(eval(expr[[1]], envir = parent.frame(1)), expr)
+		pick <- if(length(dots) > 1) names(dots[-1]) else NULL
+		if(all(is.na(power))){
+			conditions <- do.call(SimDesign::createDesign, c(dots[-1], sig.level=sig.level, power=power))
+		} else {
+			if(is.null(interval))
+				stop('search interval must be included', call.=FALSE)
+			lst_expr <- as.list(expr)[-1]
+			if(length(lst_expr))
+				lst_expr <- lst_expr[sapply(lst_expr, \(x) is.atomic(x) || is.list(x))]
+			conditions <- do.call(SimDesign::createDesign, c(lst_expr,
+															 dots[-1],
+															 sig.level=list(sig.level),
+															 power=list(power)))
+		}
+		if(!all(rowSums(is.na(conditions)) == 1))
+			stop('Exactly *one* argument must be set to \'NA\' in SpowerCurve(..., power, sig.level)',
+				 call.=FALSE)
+		power <- conditions$power
+		sig.level <- conditions$sig.level
+		if(!is.na(power[1])){
+			if(missing(integer)){
+				integer <- !(has.decimals(interval) || diff(interval) < 5)
+				if(!integer && verbose)
+					message('\nUsing continuous search interval (integer = FALSE).')
+			}
+		} else integer <- FALSE
+		control$nparent <- 2
+		out <- vector('list', nrow(conditions))
+		for(i in 1:length(out)){
+			row <- conditions[i, ]
+			tmpexpr <- expr
+			if(length(pick))
+				tmpexpr[pick] <- row[,pick]
+			out[[i]] <- do.call(Spower, c(tmpexpr,
+										  list(power=power[i], sig.level=sig.level[i], beta_alpha=NULL,
+										  interval=interval, integer=integer, replications=replications,
+										  parallel=parallel, cl=cl, predCI=predCI, predCI.tol=predCI.tol,
+										  verbose=verbose, check.interval=check.interval, sig.direction=sig.direction,
+										  maxiter=maxiter, wait.time=wait.time, select=select, control=control)))
+		}
+	} else {
+		out <- batch
+		conditions <- attr(out[[1]], 'Spower_extra')$full_conditions
 	}
 	CI.low <- CI.high <- NULL # for check?
 	main <- "Power Curve"
